@@ -16,6 +16,7 @@ use Perl6::Pod::FormattingCode::L;
 use Perl6::Pod::FormattingCode::P;
 use Perl6::Pod::FormattingCode::B;
 use Perl6::Pod::FormattingCode::I;
+use Perl6::Pod::FormattingCode::X;
 
 use Tie::UnionHash;
 use Data::Dumper;
@@ -46,6 +47,7 @@ use constant {
         'L<>'   => 'Perl6::Pod::FormattingCode::L',
         'B<>'   => 'Perl6::Pod::FormattingCode::B',
         'I<>'   => 'Perl6::Pod::FormattingCode::I',
+        'X<>'   => 'Perl6::Pod::FormattingCode::X',
 #        'P<>'   => 'Perl6::Pod::FormattingCode::P',
     }
 };
